<?php

/**
 * @file
 * Administration page callbacks for the Paragraph Comments module.
 * paragraph_comments_content_types holds array of all content types on the site.  paragraph_comments_selected_content_types holds array of content types 
 * selected in admin panel to display paragraph comments.  Both are in variables table.
 */

/**
 * Form builder.  Configure Paragraph Comments
 *
 *@ingroup forms
 *@see system_settings_form().
 */

function paragraph_comments_admin_settings() {
  // Get an array of node types with internal names as keys and
  // display names as values.  We'll output $values to create the menu where admin can select content types
  // where paragraph comments will appear.

  $types = node_type_get_types();
  foreach($types as $node_type) {
     $options[$node_type->type] = $node_type->name;
  }

 

  //Generate the form
  $form['paragraph_comments_content_types'] = array(
    '#description' => t('A clickable image and expandable div will be available on these content types to let users submit comments on each paragraph.'),
    '#type' => 'checkboxes',
    '#title' => t('Users can leave comments per paragraph on these content types'),
    '#options' => $options,
    //#default value must be same name as in $form_state if foreach loop below, note also the default value blog only gets set if paragraph_node_types is empty.
    '#default_value' => variable_get('paragraph_comments_selected_content_types'),
    
  );

   $defaultTextOption['comment_text_default'] = 'Set comment text area with text of paragraph as default';

   $form['paragraph_comments_copy_comment_as_default'] = array(
    '#title' => t('<b>Prepopulate paragraph comment textarea with paragraph text</b>'),
    '#description' => t('The comment area can be populated with the paragraph text by default.  Useful if commenters will be correcting the paragraphs'),
    '#options' => $defaultTextOption,
    '#type' => 'checkboxes',
   //this now always says true, look here http://drupal.stackexchange.com/questions/42571/how-to-check-a-checkbox-by-default-in-froms-api
   //need to do this via variable get
    //'#default_value' => array("comment_text_default"),
    '#default_value' => variable_get('comment_text_default'),
    
  );

  $form['#submit'][] = 'paragraph_comments_admin_settings_submit';
  return system_settings_form($form);

}
//on submit of settings for to select content types
function paragraph_comments_admin_settings_submit($form, $form_state) {
  $i = 0;
  //this indexed array will hold the selected content types
  $paragraph_content_type = array();
  //this array holds the default text value
  $default_text_value = array();
  //taking all the selected form values via paragraph_node_types created by form, loop,  and output as $value
  foreach ($form_state['values']['paragraph_comments_content_types'] as $key => $value) {
    //if checked add it array of content types allowed in settings variable
    $i = $i + 1;
    if ($value) {
        $paragraph_content_type[$i] = $value;
     }
  } //end foreach loop
  //Create site variable equal to the array.  We can access this via Drupal.settings.paragraph_comments.content_type in jQuery, only display our jQuery content if 
  //current node's content type is one of those selected here in the admin settings.
  //We'll actually check current content type in node full view, so we'll use Drupal.setting.paragraph_comments.current_content_type to check in jQuery.
  variable_set('paragraph_comments_selected_content_types', $paragraph_content_type);


  
  //set variable for pre-populating comment area
 foreach ($form_state['values']['paragraph_comments_copy_comment_as_default'] as $key => $value) {
    
      
      if ($value){
      $default_text_value[0] = $value;
      variable_set('comment_text_default', $default_text_value);
      //watchdog("default text is true", variable_get('comment_text_default'));
      }
      else {
        //variable_set('comment_text_default', '0');
        $default_text_value = '';
        variable_set('comment_text_default', $default_text_value);
	//watchdog("default text is false", variable_get('comment_text_default'));
      }
  }
}
